# qmake profile for abakus.
# Includes support for automatically generating the appropriate DCOP target,
# and installation and uninstallation support for the icon, .desktop file,
# and program.
#
# By Michael Pyne <michael.pyne@kdemail.net>

TEMPLATE = app
TARGET = abakus
CONFIG = debug qt yacc_no_name_mangle

# KDE installation directories
XDGDATA_APPS_DIR = $$system(kde-config --expandvars --install xdgdata-apps)
EXE_DIR = $$system(kde-config --expandvars --install exe)
ICON_DIR = $$system(kde-config --expandvars --install icon)
DATA_DIR = $$system(kde-config --expandvars --install data)
LIB_DIR = $$system(kde-config --expandvars --install lib)

# Needed to make bison and flex work.
# FYI this works with GNU Bison 1.875 and flex 2.5.4
QMAKE_YACC = bison
QMAKE_LEX = flex
QMAKE_YACCFLAGS = -d -o y.tab.c

# Link against this directory
QMAKE_LIBDIR += $$LIB_DIR
LIBS += -lkdecore -lkdeui

# Add the KDE include paths
KDEPREFIX = $$system(kde-config --prefix --expandvars)
INCLUDEPATH += . $$KDEPREFIX/include $$KDEPREFIX/include/kde

# DCOP support
kidltarget.target = dcopIface.kidl
kidltarget.commands = dcopidl dcopIface.h > $$kidltarget.target
kidltarget.depends = dcopIface.h

skeltarget.target = dcopIface_skel.cpp
skeltarget.commands = dcopidl2cpp --no-stub $$kidltarget.target
skeltarget.depends = kidltarget

# Add these targets to the generated Makefile
QMAKE_EXTRA_UNIX_TARGETS += skeltarget kidltarget

# These files are generated, so include with make clean
QMAKE_CLEAN = dcopIface.kidl dcopIface_skel.cpp dcopIface_skel.o

# These need built before we even bother with the rest of the program
PRE_TARGETDEPS = parser_yacc.o lexer_lex.o dcopIface_skel.o

target.path = $$EXE_DIR

icon.path = $$ICON_DIR/default.kde/64x64/apps
icon.files = abakus.png

menu.path = $$XDGDATA_APPS_DIR
menu.files = abakus.desktop

data.path = $$DATA_DIR/abakus
data.files = abakusui.rc

INSTALLS += icon menu data target

# Fool qmake into linking this object in.  We can't
# simply append this object to the OBJECTS variable
# because then qmake assumes that lexer.l, of all things,
# is responsible for building the object. :-(
QMAKE_LFLAGS += dcopIface_skel.o

HEADERS += abakuscommon.h \
	   abakuslistview.h \
           error_handler.h \
           function.h \
           mainwindow.h \
           node.h \
	   numerictypes.h \
           resultlistbox.h \
           resultlistboxtext.h \
	   rpnmuncher.h \
           valuemanager.h
LEXSOURCES += lexer.l
YACCSOURCES += parser.y
SOURCES += abakus.cpp \
	   abakuslistview.cpp \
           error_handler.cpp \
           function.cpp \
           mainwindow.cpp \
           node.cpp \
           resultlistbox.cpp \
           resultlistboxtext.cpp \
	   rpnmuncher.cpp \
           valuemanager.cpp
