%option noyywrap
%{
#define YY_NO_UNPUT

#include "node.h"
#include "function.h"
#include "parser_yacc.h"
#include <stdlib.h>
#include <string.h>

int yyparse(void);

// Evil global variabe used to get around yyparse() being annoying.
extern int __parserResult;
%}

DIGITS [0-9]+
HEX [0-9A-Fa-f]+
%%

 /* Always skip whitespace */
[ \t]*

 /* Power operator */
"**" { return POWER; }
"^" { return POWER; }

[sS][eE][tT] { return SET; }

[rR][eE][mM][oO][vV][eE] { return REMOVE; }

 /* Read numbers of the form with at least the decimal point and trailing
 * digits, such as .32, -234.45, .0, etc.  Numbers are only read in the BEGIN
 * state.
 */
{DIGITS}*(\.{DIGITS}+)(e[-+]?{DIGITS}+)? {
    return NUM;
}

 /* Read Hex */
0x({HEX}+)? {
    return NUM;
}

 /* Read numbers with at least the integral part, such as +4234, -34e8, etc.
 * Numbers are only read in the BEGIN state.
 */
{DIGITS}+(\.{DIGITS}*)?(e[-+]?{DIGITS}+)? {
    return NUM;
}

[nN][aA][nN] { return NUM; }
[iI][nN][fF] { return NUM; }

 /* This detects textual input, and if it isn't pre-declared by the parser (in
 * other words, if it isn't a function), then it is returned as an identifier.
 */
[a-zA-Z_][a-zA-Z_0-9]* {
    if(FunctionManager::instance()->isFunction(yytext))
	return FN;
    else {
	return ID;
    }
}

 /* All other characters are returned as-is to the parser, who can accept or
 * reject it as needed.
 */
. { return *yytext;}

%%

/* Declared in function.h, implemented here in lexer.l since this is where
 * all the yy_*() functions and types are defined.
 */
Abakus::number_t parseString(const char *str)
{
    YY_BUFFER_STATE buffer = yy_scan_string(str);
    __parserResult = 0;

    _lastParseStatusResult = yyparse();
    if(__parserResult)
	_lastParseStatusResult = __parserResult;

    yy_delete_buffer(buffer);

    return parse_result;
}
