#include <klistbox.h>
#include <klistview.h>
#include <kdebug.h>

#include <qpainter.h>
#include <qfontmetrics.h>
#include <qfont.h>

#include "resultlistboxtext.h"

QColor ResultListBoxText::m_altColor = Qt::white;
bool ResultListBoxText::m_altColorCached = false;
int ResultListBoxText::m_resultWidth = 0;

ResultListBoxText::ResultListBoxText(KListBox *listBox,
                                     const QString &text,
				     const QString &result,
				     ResultListBoxText *after,
				     bool isError)
    : QListBoxText(listBox, text, after), m_text(text), m_result(result),
      m_alternate(false), m_wasError(isError), m_stackPosition(0)
{
    if(after) {
	QListBoxItem *curItem = listBox->item(0);
	for (; !isError && curItem && curItem != this; curItem = curItem->next()) {
	    ResultListBoxText *item = dynamic_cast<ResultListBoxText *>(curItem);
	    if(!item->wasError())
		item->setStackPosition(item->stackPosition() + 1);
	}

	m_alternate = !after->drawAlternate();
    }
}

int ResultListBoxText::width(const QListBox *lb) const
{
    int minWidth = 20; // 20 is the inter-text spacing plus the padding
    minWidth += lb->fontMetrics().width(m_text);

    if(m_resultWidth == 0) {
	QString i("$999");

	// Reserve some space
	m_resultWidth = 8 + lb->fontMetrics().width(i);
    }

    minWidth += m_resultWidth;

    // We draw the result in a bold font, be sure to compensate
    QFont f(lb->font());
    f.setBold(true);
    QFontMetrics fm(f);
    
    minWidth += fm.width(m_result);

    return QMAX(minWidth, lb->width() - 2);
}

int ResultListBoxText::height(const QListBox *lb) const
{
    int offset = 28 + lb->fontMetrics().width(m_text) + m_resultWidth;
    QFont f(lb->font());
    f.setBold(true);
    QFontMetrics fm(f);
    QRect r = fm.boundingRect(0, 0, lb->width() - offset, 400, Qt::WordBreak, m_result);

    return r.height() + 10;
}

void ResultListBoxText::paint(QPainter *p)
{
    int offset = 20 + listBox()->fontMetrics().width(m_text);
    QRect r(0, 0, listBox()->visibleWidth(), height(listBox()));
    QPixmap pix(r.width(), r.height());
    QPainter painter(&pix);
    
    painter.fillRect(r, drawAlternate() ? alternateColor() : listBox()->paletteBackgroundColor());

    // Add a margin
    r.addCoords(4, 0, -m_resultWidth, 0);

    painter.setPen(listBox()->paletteForegroundColor());

    if(!m_wasError) {
	QFont oldFont(painter.font());
	QFont newFont(oldFont);
	newFont.setItalic(true);
	newFont.setPointSize(QMIN(newFont.pointSize() * 9 / 11, 10));
	painter.setFont(newFont);
	QRect result(r.right(), 0, m_resultWidth, r.height());
	painter.drawText(result, Qt::AlignCenter, QString("$%1").arg(m_stackPosition));
	painter.setFont(oldFont);
    }

    painter.drawText(r, Qt::AlignLeft | Qt::AlignVCenter, m_text);

    if(m_wasError)
	painter.setPen(m_result == "OK" ? Qt::blue : Qt::red);

    QFont f(painter.font());
    f.setBold(true);
    painter.setFont(f);

    r.addCoords(offset, 0, 0, 0);
    int alignment = Qt::AlignRight;
    if(m_wasError && m_result != "OK")
	alignment = Qt::AlignLeft;

    painter.drawText(r, Qt::WordBreak | alignment | Qt::AlignVCenter, m_result);
    p->drawPixmap(QPoint(0, 0), pix);
}

QColor ResultListBoxText::alternateColor()
{
    if(m_altColorCached)
	return m_altColor;

    // Use KListView's alternate background color
    KListView *temp = new KListView(0);
    m_altColor = temp->alternateBackground();
    delete temp;

    m_altColorCached = true;
    return m_altColor;
}

