#include <qregexp.h>

#include <math.h>

#include "valuemanager.h"

ValueManager *ValueManager::m_manager = 0;

ValueManager *ValueManager::instance()
{
    if(!m_manager)
        m_manager = new ValueManager;

    return m_manager;
}

ValueManager::ValueManager(QObject *parent, const char *name) :
    QObject(parent, name)
{
    m_values.insert("pi", M_PI);
    m_values.insert("e", M_E);
}

Abakus::number_t ValueManager::value(const QString &name) const
{
    return m_values[name];
}

bool ValueManager::isValueSet(const QString &name) const
{
    return m_values.contains(name);
}

bool ValueManager::isValueReadOnly(const QString &name) const
{
    QRegExp readOnlyValues("^(ans|pi|e)$");

    return QString(name).find(readOnlyValues) != -1;
}

void ValueManager::setValue(const QString &name, const Abakus::number_t value)
{
    if(m_values.contains(name) && this->value(name) != value)
        emit signalValueChanged(name, value);
    else if(!m_values.contains(name))
        emit signalValueAdded(name, value);

    m_values.replace(name, value);
}

void ValueManager::removeValue(const QString &name)
{
    if(m_values.contains(name))
        emit signalValueRemoved(name);

    m_values.remove(name);
}

QStringList ValueManager::valueNames() const
{
    return m_values.keys();
}

// vim: set et ts=8 sw=4:
