#ifndef _VALUEMANAGER_H
#define _VALUEMANAGER_H

#include <qobject.h>
#include <qmap.h>
#include <qstring.h>
#include <qstringlist.h>

#include "numerictypes.h"

class ValueManager : public QObject
{
    Q_OBJECT
    public:
    typedef QMap<QString, Abakus::number_t> valueMap;

    static ValueManager *instance();

    Abakus::number_t value(const QString &name) const;

    bool isValueSet(const QString &name) const;
    bool isValueReadOnly(const QString &name) const;

    void setValue(const QString &name, const Abakus::number_t value);
    void removeValue(const QString &name);

    QStringList valueNames() const;

    signals:
    void signalValueAdded(const QString &name, Abakus::number_t value);
    void signalValueRemoved(const QString &name);
    void signalValueChanged(const QString &name, Abakus::number_t newValue);

    private:
    ValueManager(QObject *parent = 0, const char *name = "value manager");

    static ValueManager *m_manager;
    valueMap m_values;
};

#endif

// vim: set et sw=4 ts=8:
